@@ -18,11 +18,10 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: fetchconfig.pl,v 1.8 2012/11/27 21:42:28 evertonm Exp $
+# $Id: fetchconfig.pl,v 1.2 2006/06/22 14:48:13 evertonm Exp $
 
 use strict;
 use fetchconfig::Logger;
-use fetchconfig::Constants;
 use fetchconfig::model::Detector;
 
 sub basename {
@@ -44,44 +43,28 @@ my $me = basename($0);
 
 my $log = fetchconfig::Logger->new({ prefix => $me });
 
-$log->info('version ' . fetchconfig::Constants::version);
-
 my @device_file_list;
-my @line_list;
 
-foreach my $opt (@ARGV) {
-    if ($opt eq '-v') {
-	exit; # only show version
-    }
-    if ($opt =~ /^-devices=(.+)$/) {
+foreach (@ARGV) {
+    if (/^-devices=(.+)$/) {
 	push @device_file_list, $1;
 	next;
     }
-    if ($opt =~ /^-line=(.+)$/) {
-	push @line_list, $1;
-	next;
-    }
-    $log->error("unexpected argument: $opt");
+    $log->error("unexpected argument: $_");
     &usage;
     die;
 }
 
-if ((@device_file_list < 1) && (@line_list < 1)){
-    $log->error("at least one -devices=filename or one -line=string is required");
+if (@device_file_list < 1) {
+    $log->error("at least one device list file is required");
     &usage;
     die;
 }
 
 fetchconfig::model::Detector->init($log);
 
-foreach my $dev_file (@device_file_list) {
-    &load_device_list($dev_file);
-}
-
-my $line_num = 0;
-foreach my $line (@line_list) {
-    ++$line_num;
-    &load_line($line, $line_num);
+foreach (@device_file_list) {
+    &load_device_list($_);
 }
 
 $log->info("done");
@@ -89,7 +72,7 @@ $log->info("done");
 exit;
 
 sub usage {
-    warn "usage: $me [-v] [-devices=file] [-line=string]\n";
+    warn "usage: $me -devices=file\n";
 }
 
 sub load_device_list {
@@ -120,13 +103,3 @@ sub load_device_list {
 		 
     close IN;
 }
-
-sub load_line {
-    my ($line, $num) = @_;
-    
-    $log->debug("loading line: line=$num [$line]");
-
-    return if ($line =~ /^\s*(#|$)/);
-
-    fetchconfig::model::Detector->parse('<cmdline>', $num, $line);
-}
