@@ -16,14 +16,13 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: Abstract.pm,v 1.11 2011/06/20 19:27:38 evertonm Exp $
+# $Id: Abstract.pm,v 1.2 2006/06/22 14:48:13 evertonm Exp $
 
 package fetchconfig::model::Abstract; # fetchconfig/model/Abstract.pm
 
 use strict;
 use warnings;
 use File::Compare;
-use POSIX qw(strftime);
 
 ####################################
 # Implement model::Abstract - Begin
@@ -50,45 +49,6 @@ sub fetch {
     die "model::Abstract->fetch: SPECIALIZE ME";
 }
 
-# chat_banner is used to allow temporary modification
-# of timeout throught the 'banner_timeout' option
-#
-sub chat_banner {
-    my ($self, $t, $dev_opt_tab, $login_pattern) = @_;
-
-    my $save_timeout;
-    my $banner_timeout = $self->dev_option($dev_opt_tab, "banner_timeout");
-
-    if (defined($banner_timeout)) {
-        $save_timeout = $t->timeout;
-        $self->log_debug("temporarily forcing banner_timeout=$banner_timeout (from timeout=$save_timeout)");
-        $t->timeout($banner_timeout);
-    }
-
-    my ($prematch, $match) = $t->waitfor(Match => $login_pattern);
-
-    if (defined($banner_timeout)) {
-        $self->log_debug("restoring timeout=$save_timeout");
-        $t->timeout($save_timeout);
-    }
-
-    ($prematch, $match);
-}
-
-sub chat_show_conf {
-    my ($self, $t, $show_cmd_default, $show_cmd_custom) = @_;
-
-    my $cmd = defined($show_cmd_custom) ? $show_cmd_custom : $show_cmd_default;
-
-    my $ok = $t->print($cmd);
-    if (!$ok) {
-	$self->log_error("could not send show config command: $cmd");
-	return 1;
-    }
-
-    undef;
-}
-
 #
 # Implement model::Abstract - End
 ##################################
@@ -105,27 +65,13 @@ sub log_error {
     $self->{log}->error($self->label . ": " . $msg);
 }
 
-# remove heading and trailing blanks
-#
-# example: " a b c  " => "a b c"
-#
-sub opt_trim {
-    my ($opt) = @_;
-    if ($opt =~ /^\s*(\S|\S.*\S)\s*$/) {
-	return $1;
-    }
-    $opt;
-}
-
 sub parse_options {
     my ($self, $label, $file, $line_num, $line, $opt_tab_ref, @options) = @_;
 
     foreach (@options) {
 	foreach (split /,/) {
-	    if (/^([^=]+)=(.*)$/) {
-		my $opt = opt_trim($1);
-		my $val = opt_trim($2);
-		$opt_tab_ref->{$opt} = $val;
+	    if (/^([^=]+)=([^=]*)$/) {
+		$opt_tab_ref->{$1} = $2;
 		next;
 	    }
 	    $self->log_error("bad $label option '$_' at file=$file line=$line_num: $line");
@@ -163,20 +109,10 @@ sub dev_option {
 }
 
 sub get_timestr {
-    my $ts = time;
-    my @local_ts_list = localtime($ts);
-    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = @local_ts_list;
+    my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = localtime(time);
     $year += 1900;
     ++$mon;
-    my $tz_off = strftime '%z', @local_ts_list; 
-    
-    # Solaris strftime does not support %z for tz offset (as in -0200),
-    # so we resort to %Z for tz name (as in -BRST)
-    if ($tz_off =~ /z/) {
-        $tz_off = strftime '-%Z', @local_ts_list;
-    }
-    
-    ($year, $mon, $mday, $hour, $min, $sec, $tz_off);
+    ($year, $mon, $mday, $hour, $min, $sec);
 }
 
 sub dump_config {
@@ -184,7 +120,7 @@ sub dump_config {
 
     my $dev_repository = $self->dev_option($dev_opt_tab, "repository");
 
-    my ($year, $mon, $day, $hour, $min, $sec, $tz_off) = get_timestr;
+    my ($year, $mon, $day, $hour, $min, $sec) = get_timestr;
 
     my $dir_path = sprintf("$dev_repository/%04d%02d/%04d%02d%02d/$dev_id",
 			   $year, $mon, $year, $mon, $day);
@@ -207,21 +143,9 @@ sub dump_config {
 	}
     }
 
-    my $dev_timezone = $self->dev_option($dev_opt_tab, "timezone");
-    if (defined($dev_timezone)) {
-	if ($dev_timezone =~ /hide/i) {
-		$tz_off = '';
-	}
-    }
-
-    my $file = sprintf("${dev_id}.run.%04d%02d%02d.%02d%02d%02d$tz_off",
+    my $file = sprintf("${dev_id}.run.%04d%02d%02d.%02d%02d%02d",
 		       $year, $mon, $day, $hour, $min, $sec);
 
-    my $dev_suffix = $self->dev_option($dev_opt_tab, "filename_append_suffix");
-    if (defined($dev_suffix)) {
-	$file .= $dev_suffix;
-    }
-
     my $file_path = "$dir_path/$file";
 
     local *OUT;
@@ -373,7 +297,7 @@ sub purge_ancient {
 
     my $dev_keep = $self->dev_option($dev_opt_tab, "keep");
     if (!defined($dev_keep)) {
-	$self->log_error("dev=$dev_id: unspecified maximum of config files to keep");
+	$self->log_error("unspecified maximum of config files to keep");
 	return;
     }
 
@@ -382,7 +306,7 @@ sub purge_ancient {
     my %dir_tab;
 
     if ($self->scan_dir(\%dir_tab, $dev_id, $dev_repository)) {
-	$self->log_error("dev=$dev_id: could not load full device config list - error scanning repository");
+	$self->log_error("could not load full device config list - error scanning repository");
 	return;
     }
 
@@ -390,8 +314,6 @@ sub purge_ancient {
 
     my $expired = @files - $dev_keep;
 
-    $self->log_debug("dev=$dev_id: expire: existing=". scalar @files . " keep=$dev_keep should_expire=$expired");
-
     return if ($expired < 1);
 
     my @sorted = sort @files;
@@ -400,7 +322,7 @@ sub purge_ancient {
 	my $file = $sorted[$i];
 	my $dir = $dir_tab{$file};
 
-	$self->log_debug("dev=$dev_id: expiring: $dir/$file");
+	$self->log_debug("expiring: $dir/$file");
 
 	$self->config_discard($dir, $file);
     }
